@@ -246,20 +246,15 @@ input[type=number]:hover,
 input[type=number]:focus,
 input[type=date]:hover,
 input[type=date]:focus,
-select:focus,
-select:hover {
-
+select:focus {
     border: 1px solid #7c7c7c;
-
-
     background: #fff;
 }
 
 input[type=text]:hover,
 input[type=password]:hover,
 input[type=number]:hover,
-input[type=date]:hover,
-select:hover {
+input[type=date]:hover {
     box-shadow: 0 1px 3px #aaa;
     -webkit-box-shadow: 0 1px 3px #aaa;
     -moz-box-shadow: 0 1px 3px #aaa;
@@ -329,10 +324,12 @@ input.button:disabled {
 
 textarea {
     overflow: visible;
+    margin: 6px;
     height: <?php echo ceil($GLOBALS['cfg']['TextareaRows'] * 1.2); ?>em;
 }
 
 textarea.char {
+    margin: 6px;
     height: <?php echo ceil($GLOBALS['cfg']['CharTextareaRows'] * 1.2); ?>em;
 }
 
@@ -3419,4 +3416,4 @@ th.headerSortUp .sorticon, th.headerSortDown:hover .sorticon {
 th.headerSortDown .sorticon, th.headerSortUp:hover .sorticon {
     background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
 }
-/* end of styles of sortable tables */
\ No newline at end of file
+/* end of styles of sortable tables */
